<?php
session_start();
require_once 'config.php';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    if (isset($_POST['action'])) {
        switch ($_POST['action']) {
            case 'add':
                $stmt = $pdo->prepare("INSERT INTO employees (name, position, salary, hire_date) VALUES (?, ?, ?, ?)");
                $stmt->execute([$_POST['name'], $_POST['position'], $_POST['salary'], $_POST['hire_date']]);
                break;
                
            case 'edit':
                $stmt = $pdo->prepare("UPDATE employees SET name = ?, position = ?, salary = ? WHERE id = ?");
                $stmt->execute([$_POST['name'], $_POST['position'], $_POST['salary'], $_POST['employee_id']]);
                break;
                
            case 'delete':
                $stmt = $pdo->prepare("DELETE FROM employees WHERE id = ?");
                $stmt->execute([$_POST['employee_id']]);
                break;
        }
    }
}

$employees = $pdo->query("SELECT * FROM employees ORDER BY name")->fetchAll();
?>

<!DOCTYPE html>
<html dir="rtl">
<head>
    <title>إدارة الموظفين</title>
    <style>
        body {
            font-family: 'Arial', sans-serif;
            background: #f4f4f4;
            margin: 0;
            padding: 20px;
        }
        .container {
            max-width: 1000px;
            margin: 0 auto;
            background: white;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 0 10px rgba(0,0,0,0.1);
        }
        table {
            width: 100%;
            border-collapse: collapse;
            margin-top: 20px;
        }
        th, td {
            padding: 10px;
            border: 1px solid #ddd;
            text-align: right;
        }
        th {
            background: #f5f5f5;
        }
        .btn {
            padding: 5px 10px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            color: white;
        }
        .btn-edit {
            background: #2196F3;
        }
        .btn-delete {
            background: #f44336;
        }
        .add-form {
            margin-bottom: 20px;
            padding: 15px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }
    </style>
</head>
<body>
    <div class="container">
        <h2>إدارة الموظفين</h2>
        
        <div class="add-form">
            <h3>إضافة موظف جديد</h3>
            <form method="POST">
                <input type="hidden" name="action" value="add">
                <input type="text" name="name" placeholder="اسم الموظف" required>
                <input type="text" name="position" placeholder="المنصب" required>
                <input type="number" name="salary" placeholder="الراتب" required>
                <input type="date" name="hire_date" required>
                <button type="submit" class="btn btn-edit">إضافة</button>
            </form>
        </div>
        
        <table>
            <thead>
                <tr>
                    <th>الاسم</th>
                    <th>المنصب</th>
                    <th>الراتب</th>
                    <th>تاريخ التعيين</th>
                    <th>الإجراءات</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($employees as $employee): ?>
                <tr>
                    <td><?php echo htmlspecialchars($employee['name']); ?></td>
                    <td><?php echo htmlspecialchars($employee['position']); ?></td>
                    <td><?php echo htmlspecialchars($employee['salary']); ?></td>
                    <td><?php echo htmlspecialchars($employee['hire_date']); ?></td>
                    <td>
                        <button class="btn btn-edit" onclick="editEmployee(<?php echo $employee['id']; ?>)">تعديل</button>
                        <form method="POST" style="display: inline;">
                            <input type="hidden" name="action" value="delete">
                            <input type="hidden" name="employee_id" value="<?php echo $employee['id']; ?>">
                            <button type="submit" class="btn btn-delete" onclick="return confirm('هل أنت متأكد من الحذف؟')">حذف</button>
                        </form>
                    </td>
                </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>
</body>
</html>