<?php
session_start();
require_once 'config.php';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    try {
        $pdo->beginTransaction();
        
        // إدخال بيانات العميل
        $stmt = $pdo->prepare("INSERT INTO customers (name, phone, address) VALUES (?, ?, ?)");
        $stmt->execute([$_POST['customer_name'], $_POST['customer_phone'], $_POST['customer_address']]);
        $customer_id = $pdo->lastInsertId();
        
        // إنشاء رقم العقد والباركود
        $contract_number = date('Y') . sprintf("%06d", rand(1, 999999));
        $barcode = uniqid();
        
        // إدخال العقد
        $stmt = $pdo->prepare("INSERT INTO contracts (contract_number, barcode, customer_id, department, date_created, total_amount, paid_amount, remaining_amount, tax_rate, status) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
        $stmt->execute([
            $contract_number,
            $barcode,
            $customer_id,
            $_POST['department'],
            date('Y-m-d'),
            $_POST['total_amount'],
            $_POST['paid_amount'],
            $_POST['total_amount'] - $_POST['paid_amount'],
            $_POST['tax_rate'],
            'active'
        ]);
        
        $contract_id = $pdo->lastInsertId();
        
        // إدخال تفاصيل العقد
        foreach ($_POST['items'] as $item) {
            $stmt = $pdo->prepare("INSERT INTO contract_items (contract_id, item_description, quantity, unit, unit_price, total_price) VALUES (?, ?, ?, ?, ?, ?)");
            $stmt->execute([
                $contract_id,
                $item['description'],
                $item['quantity'],
                $item['unit'],
                $item['unit_price'],
                $item['quantity'] * $item['unit_price']
            ]);
        }
        
        $pdo->commit();
        header('Location: view_contract.php?id=' . $contract_id);
        exit();
    } catch (Exception $e) {
        $pdo->rollBack();
        $error = "حدث خطأ في إنشاء العقد";
    }
}
?>

<!DOCTYPE html>
<html dir="rtl">
<head>
    <title>إضافة عقد جديد</title>
    <style>
        body {
            font-family: 'Arial', sans-serif;
            background: #f4f4f4;
            margin: 0;
            padding: 20px;
        }
        .contract-form {
            max-width: 800px;
            margin: 0 auto;
            background: white;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 0 10px rgba(0,0,0,0.1);
        }
        .form-group {
            margin-bottom: 15px;
        }
        label {
            display: block;
            margin-bottom: 5px;
        }
        input, select {
            width: 100%;
            padding: 8px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }
        .items-container {
            border: 1px solid #ddd;
            padding: 15px;
            margin: 15px 0;
        }
        .btn {
            padding: 10px 20px;
            background: #4CAF50;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
        }
        .btn-add {
            background: #2196F3;
        }
    </style>
    <script>
        function addItem() {
            const container = document.getElementById('items-container');
            const itemDiv = document.createElement('div');
            itemDiv.className = 'form-group';
            itemDiv.innerHTML = `
                <input type="text" name="items[][description]" placeholder="وصف المنتج" required>
                <input type="number" name="items[][quantity]" placeholder="الكمية" required>
                <select name="items[][unit]">
                    <option value="piece">قطعة</option>
                    <option value="meter">متر</option>
                    <option value="sqm">متر مربع</option>
                </select>
                <input type="number" name="items[][unit_price]" placeholder="سعر الوحدة" required>
            `;
            container.appendChild(itemDiv);
        }
    </script>
</head>
<body>
    <div class="contract-form">
        <h2>إضافة عقد جديد</h2>
        
        <form method="POST">
            <div class="form-group">
                <label>اسم العميل</label>
                <input type="text" name="customer_name" required>
            </div>
            
            <div class="form-group">
                <label>رقم الهاتف</label>
                <input type="text" name="customer_phone" required>
            </div>
            
            <div class="form-group">
                <label>العنوان</label>
                <input type="text" name="customer_address" required>
            </div>
            
            <div class="form-group">
                <label>القسم</label>
                <select name="department" required>
                    <option value="wood">النجارة</option>
                    <option value="aluminum">الألمنيوم</option>
                </select>
            </div>
            
            <div class="form-group">
                <label>نسبة الضريبة (%)</label>
                <input type="number" name="tax_rate" value="15" required>
            </div>
            
            <div id="items-container" class="items-container">
                <h3>المنتجات</h3>
            </div>
            
            <button type="button" class="btn btn-add" onclick="addItem()">إضافة منتج</button>
            
            <div class="form-group">
                <label>المبلغ المدفوع مقدماً</label>
                <input type="number" name="paid_amount" required>
            </div>
            
            <button type="submit" class="btn">حفظ العقد</button>
        </form>
    </div>
</body>
</html>