<?php
session_start();
require_once 'config.php';

$contract_id = isset($_GET['id']) ? $_GET['id'] : 0;

$stmt = $pdo->prepare("
    SELECT 
        c.*,
        cust.name as customer_name,
        cust.phone as customer_phone,
        cust.address as customer_address
    FROM contracts c
    JOIN customers cust ON c.customer_id = cust.id
    WHERE c.id = ?
");
$stmt->execute([$contract_id]);
$contract = $stmt->fetch();

$stmt = $pdo->prepare("SELECT * FROM contract_items WHERE contract_id = ?");
$stmt->execute([$contract_id]);
$items = $stmt->fetchAll();
?>

<!DOCTYPE html>
<html dir="rtl">
<head>
    <title>طباعة فاتورة</title>
    <style>
        body {
            font-family: 'Arial', sans-serif;
            margin: 0;
            padding: 20px;
        }
        .invoice {
            max-width: 800px;
            margin: 0 auto;
            padding: 20px;
            border: 1px solid #ddd;
        }
        .header {
            text-align: center;
            margin-bottom: 20px;
        }
        .logo {
            max-width: 200px;
            margin-bottom: 10px;
        }
        .customer-info {
            margin-bottom: 20px;
            padding: 10px;
            background: #f9f9f9;
        }
        table {
            width: 100%;
            border-collapse: collapse;
            margin-bottom: 20px;
        }
        th, td {
            padding: 10px;
            border: 1px solid #ddd;
            text-align: right;
        }
        .totals {
            text-align: left;
            margin-top: 20px;
        }
        @media print {
            .no-print {
                display: none;
            }
        }
    </style>
</head>
<body>
    <div class="invoice">
        <div class="header">
            <img src="logo.png" alt="شعار الورشة" class="logo">
            <h1>فاتورة ضريبية</h1>
            <p>رقم الفاتورة: <?php echo $contract['contract_number']; ?></p>
            <p>التاريخ: <?php echo $contract['date_created']; ?></p>
        </div>
        
        <div class="customer-info">
            <h3>معلومات العميل</h3>
            <p>الاسم: <?php echo $contract['customer_name']; ?></p>
            <p>الهاتف: <?php echo $contract['customer_phone']; ?></p>
            <p>العنوان: <?php echo $contract['customer_address']; ?></p>
        </div>
        
        <table>
            <thead>
                <tr>
                    <th>الوصف</th>
                    <th>الكمية</th>
                    <th>الوحدة</th>
                    <th>السعر</th>
                    <th>الإجمالي</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($items as $item): ?>
                <tr>
                    <td><?php echo htmlspecialchars($item['item_description']); ?></td>
                    <td><?php echo htmlspecialchars($item['quantity']); ?></td>
                    <td><?php echo htmlspecialchars($item['unit']); ?></td>
                    <td><?php echo number_format($item['unit_price'], 2); ?></td>
                    <td><?php echo number_format($item['total_price'], 2); ?></td>
                </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
        
        <div class="totals">
            <p>المجموع قبل الضريبة: <?php echo number_format($contract['total_amount'] / (1 + $contract['tax_rate']/100), 2); ?></p>
            <p>الضريبة (<?php echo $contract['tax_rate']; ?>%): <?php echo number_format($contract['total_amount'] * ($contract['tax_rate']/100) / (1 + $contract['tax_rate']/100), 2); ?></p>
            <p>المجموع النهائي: <?php echo number_format($contract['total_amount'], 2); ?></p>
            <p>المدفوع: <?php echo number_format($contract['paid_amount'], 2); ?></p>
            <p>المتبقي: <?php echo number_format($contract['remaining_amount'], 2); ?></p>
        </div>
        
        <button onclick="window.print()" class="no-print">طباعة</button>
    </div>
</body>
</html>