<?php
session_start();
require_once 'config.php';

$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-01');
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');
$department = isset($_GET['department']) ? $_GET['department'] : 'wood';

$stmt = $pdo->prepare("
    SELECT 
        c.contract_number,
        c.date_created,
        cust.name as customer_name,
        c.total_amount,
        c.paid_amount,
        c.remaining_amount,
        c.tax_rate
    FROM contracts c
    JOIN customers cust ON c.customer_id = cust.id
    WHERE c.department = ? 
    AND c.date_created BETWEEN ? AND ?
    ORDER BY c.date_created DESC
");
$stmt->execute([$department, $start_date, $end_date]);
$contracts = $stmt->fetchAll();

// حساب الإجماليات
$total_amount = array_sum(array_column($contracts, 'total_amount'));
$total_paid = array_sum(array_column($contracts, 'paid_amount'));
$total_remaining = array_sum(array_column($contracts, 'remaining_amount'));
?>

<!DOCTYPE html>
<html dir="rtl">
<head>
    <title>التقارير المالية</title>
    <style>
        body {
            font-family: 'Arial', sans-serif;
            background: #f4f4f4;
            margin: 0;
            padding: 20px;
        }
        .container {
            max-width: 1200px;
            margin: 0 auto;
            background: white;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 0 10px rgba(0,0,0,0.1);
        }
        .filters {
            margin-bottom: 20px;
            padding: 15px;
            background: #f9f9f9;
            border-radius: 4px;
        }
        table {
            width: 100%;
            border-collapse: collapse;
        }
        th, td {
            padding: 10px;
            border: 1px solid #ddd;
            text-align: right;
        }
        th {
            background: #f5f5f5;
        }
        .summary {
            margin-top: 20px;
            padding: 15px;
            background: #e8f5e9;
            border-radius: 4px;
        }
        .btn-print {
            padding: 10px 20px;
            background: #4CAF50;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
        }
    </style>
</head>
<body>
    <div class="container">
        <h2>التقارير المالية</h2>
        
        <div class="filters">
            <form method="GET">
                <label>القسم:</label>
                <select name="department">
                    <option value="wood" <?php echo $department == 'wood' ? 'selected' : ''; ?>>النجارة</option>
                    <option value="aluminum" <?php echo $department == 'aluminum' ? 'selected' : ''; ?>>الألمنيوم</option>
                </select>
                
                <label>من تاريخ:</label>
                <input type="date" name="start_date" value="<?php echo $start_date; ?>">
                
                <label>إلى تاريخ:</label>
                <input type="date" name="end_date" value="<?php echo $end_date; ?>">
                
                <button type="submit">عرض</button>
            </form>
        </div>
        
        <table>
            <thead>
                <tr>
                    <th>رقم العقد</th>
                    <th>التاريخ</th>
                    <th>اسم العميل</th>
                    <th>المبلغ الإجمالي</th>
                    <th>المدفوع</th>
                    <th>المتبقي</th>
                    <th>الضريبة</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($contracts as $contract): ?>
                <tr>
                    <td><?php echo htmlspecialchars($contract['contract_number']); ?></td>
                    <td><?php echo htmlspecialchars($contract['date_created']); ?></td>
                    <td><?php echo htmlspecialchars($contract['customer_name']); ?></td>
                    <td><?php echo number_format($contract['total_amount'], 2); ?></td>
                    <td><?php echo number_format($contract['paid_amount'], 2); ?></td>
                    <td><?php echo number_format($contract['remaining_amount'], 2); ?></td>
                    <td><?php echo number_format($contract['tax_rate'], 2); ?>%</td>
                </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
        
        <div class="summary">
            <h3>ملخص</h3>
            <p>إجمالي المبالغ: <?php echo number_format($total_amount, 2); ?></p>
            <p>إجمالي المدفوعات: <?php echo number_format($total_paid, 2); ?></p>
            <p>إجمالي المتبقي: <?php echo number_format($total_remaining, 2); ?></p>
        </div>
        
        <button onclick="window.print()" class="btn-print">طباعة التقرير</button>
    </div>
</body>
</html>